==> vue-pop-upload-2.24.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import "@opentinyvue/vue-theme/pop-upload/index.css";
var template = function template2(mode) {
  var _process$env;
  typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  return PcTemplate;
};
var $constants = {
  KB: "KB",
  FILE_NAME: "ui.popupload.fileName",
  FILE_SIZE: "ui.popupload.fileSize",
  FILE_STATUS: "ui.popupload.fileStatus",
  DIALOG_TITLE: "ui.popupload.dialogTitle",
  UPLOAD_ERROR: "ui.popupload.uploadError",
  ERROR_NUM_TIPS: "ui.popupload.errorNumTips",
  UPLOAD_SUCCESS: "ui.popupload.uploadSuccess",
  TIPS_TITLE_TEXT: "ui.popupload.tipsFileText",
  ERROR_TYPE_TIPS: "ui.popupload.errorTypeTips",
  ERROR_SIZE_TIPS: "ui.popupload.errorSizeTips",
  SAVE_BUTTON_TEXT: "ui.popupload.saveButtonText",
  UPLOAD_BUTTON_TEXT: "ui.popupload.uploadButtonText",
  CANCEL_BUTTTON_TEXT: "ui.popupload.cancelButtonText",
  UPLOADS_BUTTON_TEXT: "ui.popupload.uploadsButtonText",
  LIMIT_UPLOAD_FILE_TYPE: "ui.popupload.limitUploadFileType",
  LIMIT_UPLOAD_FILE_SIZE: "ui.popupload.limitUploadFileSize",
  LIMIT_UPLOAD_FILE_NUMBER: "ui.popupload.limitUploadFileNumber"
};
var PopUpload = defineComponent({
  name: $prefix + "PopUpload",
  props: _extends({}, $props, {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    size: {
      type: String,
      default: "",
      validator: function validator(val) {
        return ["large", "medium", "small", "mini", ""].includes(val);
      }
    },
    data: Object,
    uploadName: String,
    dialogTitle: {
      type: String,
      default: ""
    },
    action: {
      type: String,
      default: ""
    },
    uploadButtonText: {
      type: String,
      default: ""
    },
    headers: {
      type: Object,
      default: function _default2() {
        return {};
      }
    },
    withCredentials: {
      type: Boolean,
      default: false
    },
    limit: Number,
    multiple: Boolean,
    disabled: {
      type: Boolean,
      default: false
    },
    accept: String,
    submitButtonText: {
      typee: String,
      default: ""
    },
    cancelButtonText: {
      typee: String,
      default: ""
    },
    uploadFileType: Array,
    beforeUpload: Function,
    beforeRemove: Function,
    maxUploadFileSize: Number,
    httpRequest: Function
  }),
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.undefined";
PopUpload.install = function(Vue) {
  Vue.component(PopUpload.name, PopUpload);
};
PopUpload.version = version;
export {
  PopUpload as default
};

==> vue-pop-upload-3.21.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $prefix, $props, $setup } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import "@opentinyvue/vue-theme/pop-upload/index.css";
var template = function template2(mode) {
  var _process$env;
  typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  return PcTemplate;
};
var $constants = {
  KB: "KB",
  FILE_NAME: "ui.popupload.fileName",
  FILE_SIZE: "ui.popupload.fileSize",
  FILE_STATUS: "ui.popupload.fileStatus",
  DIALOG_TITLE: "ui.popupload.dialogTitle",
  UPLOAD_ERROR: "ui.popupload.uploadError",
  ERROR_NUM_TIPS: "ui.popupload.errorNumTips",
  UPLOAD_SUCCESS: "ui.popupload.uploadSuccess",
  TIPS_TITLE_TEXT: "ui.popupload.tipsFileText",
  ERROR_TYPE_TIPS: "ui.popupload.errorTypeTips",
  ERROR_SIZE_TIPS: "ui.popupload.errorSizeTips",
  SAVE_BUTTON_TEXT: "ui.popupload.saveButtonText",
  UPLOAD_BUTTON_TEXT: "ui.popupload.uploadButtonText",
  CANCEL_BUTTTON_TEXT: "ui.popupload.cancelButtonText",
  UPLOADS_BUTTON_TEXT: "ui.popupload.uploadsButtonText",
  LIMIT_UPLOAD_FILE_TYPE: "ui.popupload.limitUploadFileType",
  LIMIT_UPLOAD_FILE_SIZE: "ui.popupload.limitUploadFileSize",
  LIMIT_UPLOAD_FILE_NUMBER: "ui.popupload.limitUploadFileNumber"
};
var PopUpload = defineComponent({
  name: $prefix + "PopUpload",
  props: _extends({}, $props, {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    size: String,
    data: Object,
    uploadName: String,
    dialogTitle: {
      type: String,
      default: ""
    },
    action: {
      type: String,
      default: ""
    },
    uploadButtonText: {
      type: String,
      default: ""
    },
    headers: {
      type: Object,
      default: function _default2() {
        return {};
      }
    },
    withCredentials: {
      type: Boolean,
      default: false
    },
    limit: Number,
    multiple: Boolean,
    disabled: {
      type: Boolean,
      default: false
    },
    accept: String,
    submitButtonText: {
      typee: String,
      default: ""
    },
    cancelButtonText: {
      typee: String,
      default: ""
    },
    uploadFileType: Array,
    beforeUpload: Function,
    beforeRemove: Function,
    maxUploadFileSize: Number,
    httpRequest: Function
  }),
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "3.21.0";
PopUpload.install = function(Vue) {
  Vue.component(PopUpload.name, PopUpload);
};
PopUpload.version = version;
export {
  PopUpload as default
};
